@@ -1,20 +1,14 @@
 package Netflow::Collector;
-$Netflow::Collector::VERSION = '0.01';
-{
-
-    package Netflow::Collector::Exception;
-    use Moose;
-    extends 'Throwable::Error';
-    use namespace::autoclean;
-    no Moose;
-    1;
-}
+$Netflow::Collector::VERSION = '0.02';
 
 use v5.10;
 use Moose;
 use Moose::Util::TypeConstraints;
 use namespace::autoclean;
-
+use sigtrap qw/
+    die
+    normal-signals
+    /;
 use Netflow::Collector::Exception;
 use IO::Socket::INET;
 use IO::Select;
@@ -29,7 +23,7 @@ Netflow::Collector
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
@@ -58,9 +52,11 @@ for a received packets responsible code reference
 
 =cut
 
-has "dispatch",
+has "_dispatch",
     is       => "ro",
     isa      => "CodeRef",
+    init_arg => "dispatch",
+    clearer  => "_clear_dispatch",
     required => 1;
 
 =head2 port
@@ -78,7 +74,7 @@ has "port",
 
 if defined will be provided to
 
-C<IO::Socket::INET->setsockopt(SOL_SOCKET, SO_RCVBUF, $self->max_rcv_buf)>
+    IO::Socket::INET->setsockopt(SOL_SOCKET, SO_RCVBUF, $self->max_rcv_buf)
 
 =cut
 
@@ -160,10 +156,14 @@ sub run {
     my ($self) = shift;
     my $sock = $self->_socket();
     while ($sock->recv(my $packet, $self->max_pkt_size)) {
-        $self->dispatch->($packet);
+        $self->_dispatch->($packet);
     }
 } ## end sub run
 
+sub DEMOLISH {
+    shift->_clear_dispatch();
+}
+
 no Moose;
 __PACKAGE__->meta->make_immutable;
 1;    # End of Netflow::Collector
